import { UX } from '@salesforce/command';
import { Logger } from '@salesforce/core';
import { DeployResult, MetadataApiDeployStatus, RequestStatus } from '@salesforce/source-deploy-retrieve';
import { CoverageResultsFileInfo, ResultFormatter, ResultFormatterOptions } from '../resultFormatter';
export type MdDeployResult = MetadataApiDeployStatus & {
    coverage?: CoverageResultsFileInfo;
    junit?: string;
};
export declare class MdDeployResultFormatter extends ResultFormatter {
    protected result: DeployResult;
    constructor(logger: Logger, ux: UX, options: ResultFormatterOptions, result: DeployResult);
    /**
     * Get the JSON output from the DeployResult.
     *
     * @returns a JSON formatted result matching the provided type.
     */
    getJson(): MdDeployResult;
    /**
     * @param isReportCommand set to true if the command is deploy:report.  The output is slightly different
     * Displays deploy results in human readable format.  Output can vary based on:
     *
     * 1. Verbose option
     * 3. Checkonly deploy (checkonly=true)
     * 4. Deploy with test results
     * 5. Canceled status
     */
    display(isReportCommand?: boolean): void;
    protected hasStatus(status: RequestStatus): boolean;
    protected getResponse(): MdDeployResult;
    protected displaySuccesses(): void;
    protected displayFailures(): void;
    protected getNumResult(field: string): number;
    protected displayTestResults(isReportCommand?: boolean): void;
    protected verboseTestFailures(): void;
    protected verboseTestSuccess(): void;
    protected verboseTestTime(): void;
}
