import { UX } from '@salesforce/command';
import { Logger } from '@salesforce/core';
import { RetrieveResult, MetadataApiRetrieveStatus, FileResponse, RetrieveMessage } from '@salesforce/source-deploy-retrieve';
import { RetrieveFormatter } from './retrieveFormatter';
import { ResultFormatterOptions } from './resultFormatter';
export interface PackageRetrieval {
    name: string;
    path: string;
}
export interface RetrieveResultFormatterOptions extends ResultFormatterOptions {
    packages?: PackageRetrieval[];
}
export interface RetrieveCommandResult {
    inboundFiles: FileResponse[];
    packages: PackageRetrieval[];
    warnings: RetrieveMessage[];
    response: MetadataApiRetrieveStatus;
}
export declare class RetrieveResultFormatter extends RetrieveFormatter {
    protected packages: PackageRetrieval[];
    protected fileResponses: FileResponse[];
    constructor(logger: Logger, ux: UX, options: RetrieveResultFormatterOptions, result: RetrieveResult);
    /**
     * Get the JSON output from the RetrieveResult.
     *
     * @returns RetrieveCommandResult
     */
    getJson(): RetrieveCommandResult;
    /**
     * Displays retrieve results in human format.
     */
    display(): void;
    private displaySuccesses;
}
